/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package handler

import (
	"context"

	"github.com/apache/answer/internal/base/constant"
	"github.com/gin-gonic/gin"
	"github.com/segmentfault/pacman/i18n"
)

// GetLangByCtx get language from header
func GetLangByCtx(ctx context.Context) i18n.Language {
	if ginCtx, ok := ctx.(*gin.Context); ok {
		acceptLanguage, ok := ginCtx.Get(constant.AcceptLanguageFlag)
		if ok {
			if acceptLanguage, ok := acceptLanguage.(i18n.Language); ok {
				return acceptLanguage
			}
			return i18n.DefaultLanguage
		}
	}

	acceptLanguage, ok := ctx.Value(constant.AcceptLanguageContextKey).(i18n.Language)
	if ok {
		return acceptLanguage
	}
	return i18n.DefaultLanguage
}
